@@ -1,22 +1,28 @@
 # -*- coding: utf-8 -*-
 import logging
-from dateutil.parser import parse as parse_date
 from tempfile import TemporaryFile
 
+from dateutil.parser import parse as parse_date
 from django.core.files.storage import Storage
 from django.utils import timezone
-from django.conf import settings as _settings
 
+try:
+    from django.utils.deconstruct import deconstructible
+except ImportError:
+    def deconstructible(func):
+        return func
+
+from django.conf import settings as _settings
 from boto import connect_s3
 from boto.s3.connection import Location
 from boto.exception import S3CreateError, S3ResponseError
-
 from django_boto import settings
 
 
 logger = logging.getLogger(__name__)
 
 
+@deconstructible
 class S3Storage(Storage):
 
     """
@@ -35,7 +41,8 @@ class S3Storage(Storage):
         self.force_http = force_http_url if force_http_url else settings.AWS_S3_FORCE_HTTP_URL
         self.replace = replace
 
-        self.location = getattr(Location, self.location)
+        if hasattr(Location, self.location):
+            self.location = getattr(Location, self.location)
 
         self._bucket = None
 
